Preprocessor directives and asm statements should be
allowed to have a line continuation.

Signed-off-by: Joe Perches <j...@perches.com>
---
 scripts/checkpatch.pl |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)

diff --git a/scripts/checkpatch.pl b/scripts/checkpatch.pl
index d2d5ba1..019f9be 100755
--- a/scripts/checkpatch.pl
+++ b/scripts/checkpatch.pl
@@ -3006,10 +3006,12 @@ sub process {
                                }
                        }
 
 # check for line continuations outside of #defines
 
                } else {
                        if ($prevline !~ /^..*\\$/ &&
+                           $line !~ /^\+\s*\#*.*\\$/ &&        # preprocessor
+                           $line !~ /^\+.*\b(__asm__|asm)\b.*\\$/ &&   # asm
                            $line =~ /^\+.*\\$/) {
                                WARN("LINE_CONTINUATIONS",
                                     "Avoid unnecessary line continuations\n" . 
@@ -3006,10 +3006,12 @@ sub process {
                        }
 
-# check for line continuations outside of #defines
+# check for line continuations outside of #defines, preprocessor #, and asm
 
                } else {
$herecurr);


--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to